/*
 * $Id: config.cpp,v 1.2 2002/09/01 22:50:34 fredrik Exp $
 * 
 * Keramik KWin client configuration module
 *
 * Copyright (C) 2002 Fredrik Hglund <fredrik@kde.org>
 *
 * Based on the Quartz configuration module,
 *     Copyright (c) 2001 Karol Szwed <gallium@kde.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the license, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
 
#include <kglobal.h>
#include <klocale.h>

#include <qcheckbox.h>
#include <qspinbox.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>

#include "config.h"
#include "config.moc"

extern "C"
{
	QObject* allocate_config( KConfig* conf, QWidget* parent )
	{
		return ( new KbCrystLunaConfig( conf, parent ) );
	}
}


/* NOTE: 
 * 'conf' 	is a pointer to the kwindecoration modules open kwin config,
 *			and is by default set to the "Style" group.
 *
 * 'parent'	is the parent of the QObject, which is a VBox inside the
 *			Configure tab in kwindecoration
 */

KbCrystLunaConfig::KbCrystLunaConfig( KConfig* conf, QWidget* parent )
	: QObject( parent )
{
	KGlobal::locale()->insertCatalogue("kwin_kbcrystluna_config");
	c = new KConfig( "kwinkbcrystlunarc" );
	
	ui = new KbCrystLunaConfigUI( parent );
	connect( ui->useButtonColor, SIGNAL(clicked()), SIGNAL(changed()) );
	connect( ui->useShadowedText, SIGNAL(clicked()), SIGNAL(changed()) );
	connect( ui->purposeTitleblendColor, SIGNAL(clicked(int)), this, SIGNAL(changed()) );
	connect( ui->customButtonSpacing, SIGNAL(valueChanged(int)),
		this, SIGNAL(changed()));
	connect( ui->titlebarHeightOffset, SIGNAL(valueChanged(int)),
		this, SIGNAL(changed()));
	connect( ui->titlebuttonMargineAddition, SIGNAL(valueChanged(int)),
		this, SIGNAL(changed()));
	load( conf );
	ui->show();
}


KbCrystLunaConfig::~KbCrystLunaConfig()
{
	delete ui;
	delete c;
}


// Loads the configurable options from the kwinrc config file
// It is passed the open config from kwindecoration to improve efficiency
void KbCrystLunaConfig::load( KConfig* )
{
	c->setGroup("General");
	ui->useButtonColor->setChecked( c->readBoolEntry("UseButtonColor", false) );
	ui->useShadowedText->setChecked( c->readBoolEntry("UseShadowedText", true) );
	if (c->readBoolEntry("UseTitleBlendColorForButton", false)) {
	        ui->purposeTitleblendColor->setButton(1);
	} else {
	        ui->purposeTitleblendColor->setButton(0);
	}
	ui->customButtonSpacing->setValue( c->readNumEntry("ButtonSpacing", 4) );
	ui->titlebarHeightOffset->setValue( c->readNumEntry("TitlebarHeightOffset", 0) );
	ui->titlebuttonMargineAddition->setValue( c->readNumEntry("TitlebuttonMargineAddition", 0) );
}


// Saves the configurable options to the kwinrc config file
void KbCrystLunaConfig::save( KConfig* )
{
	c->setGroup( "General" );
	c->writeEntry( "ShowAppIcons", true );
	c->writeEntry( "SmallCaptionBubbles", false );
	c->writeEntry( "LargeGrabBars", false);
	c->writeEntry( "UseButtonColor", ui->useButtonColor->isChecked() );
	c->writeEntry( "UseShadowedText", ui->useShadowedText->isChecked() );
	c->writeEntry( "ButtonSpacing", ui->customButtonSpacing->value() );
	c->writeEntry( "TitlebarHeightOffset", ui->titlebarHeightOffset->value() );
	c->writeEntry( "TitlebuttonMargineAddition", ui->titlebuttonMargineAddition->value() );

	QRadioButton *ptc = (QRadioButton*)ui->purposeTitleblendColor->selected();
	QString ptcSelected = QString(ptc->name());
	if (ptcSelected.compare("winborder") == 0) {
	        c->writeEntry("UseTitleBlendColorForButton", false);
	} else {
	        c->writeEntry("UseTitleBlendColorForButton", true);
	}

	c->sync();
}


// Sets UI widget defaults which must correspond to style defaults
void KbCrystLunaConfig::defaults()
{
	ui->useButtonColor->setChecked( false );
	ui->useShadowedText->setChecked( true );
	ui->customButtonSpacing->setValue(4);
	ui->titlebarHeightOffset->setValue(0);
	ui->purposeTitleblendColor->setButton(0);
	ui->titlebuttonMargineAddition->setValue(0);

	emit changed();
}

// vim: set noet ts=4 sw=4:
